==> haskell-interpolatedstring-perl6-1.0.2-375-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-interpolatedstring-perl6.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 interpolatedstring-perl6
version:              1.0.2
visibility:           public
id:                   interpolatedstring-perl6-1.0.2-LBuZ9TjXV5J7i6LvxfF3DI
key:                  interpolatedstring-perl6-1.0.2-LBuZ9TjXV5J7i6LvxfF3DI
license:              LicenseRef-PublicDomain
copyright:            Audrey Tang
maintainer:           Audrey Tang <audreyt@audreyt.org>
author:               Audrey Tang
stability:            stable
synopsis:             QuasiQuoter for Perl6-style multi-line interpolated strings
description:
    QuasiQuoter for Perl6-style multi-line interpolated strings with \"q\", \"qq\" and \"qc\" support.

category:             Data
abi:                  0295a8492f324e99ecc2b9d87fc27474
exposed:              True
exposed-modules:      Text.InterpolatedString.Perl6
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/interpolatedstring-perl6-1.0.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/interpolatedstring-perl6-1.0.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/interpolatedstring-perl6-1.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-interpolatedstring-perl6
hs-libraries:         HSinterpolatedstring-perl6-1.0.2-LBuZ9TjXV5J7i6LvxfF3DI
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    haskell-src-meta-0.8.15-8SayVusso5pEmfrM7EgUy8
    template-haskell-2.19.0.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-interpolatedstring-perl6/html/interpolatedstring-perl6.haddock

haddock-html:         /usr/share/doc/haskell-interpolatedstring-perl6/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-interpolatedstring-perl6-1.0.2-376-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-interpolatedstring-perl6.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 interpolatedstring-perl6
version:              1.0.2
visibility:           public
id:                   interpolatedstring-perl6-1.0.2-Go8nB3b0Cnv9R3Tpb72oKW
key:                  interpolatedstring-perl6-1.0.2-Go8nB3b0Cnv9R3Tpb72oKW
license:              LicenseRef-PublicDomain
copyright:            Audrey Tang
maintainer:           Audrey Tang <audreyt@audreyt.org>
author:               Audrey Tang
stability:            stable
synopsis:             QuasiQuoter for Perl6-style multi-line interpolated strings
description:
    QuasiQuoter for Perl6-style multi-line interpolated strings with \"q\", \"qq\" and \"qc\" support.

category:             Data
abi:                  3e65fecccfaf7df2015ad820e1290d62
exposed:              True
exposed-modules:      Text.InterpolatedString.Perl6
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/interpolatedstring-perl6-1.0.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/interpolatedstring-perl6-1.0.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/interpolatedstring-perl6-1.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-interpolatedstring-perl6
hs-libraries:         HSinterpolatedstring-perl6-1.0.2-Go8nB3b0Cnv9R3Tpb72oKW
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    haskell-src-meta-0.8.15-59C8VP65IXC97VdMxnGw0a
    template-haskell-2.19.0.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-interpolatedstring-perl6/html/interpolatedstring-perl6.haddock

haddock-html:         /usr/share/doc/haskell-interpolatedstring-perl6/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
